this is a library that make you able to execute fonction on a command line tool with some cool pre build function!
with the 2.0.1 update you can pass parameter with the command line (yes it is obvius that we can but it is why i did implement it!)
